"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("util");
const winston_1 = require("winston");
const transports_1 = require("winston/lib/winston/transports");
const colors = {
    bold: (text) => `\x1B[1m${text}\x1B[0m`,
    red: (text) => `\x1B[31m${text}\x1B[39m`,
    green: (text) => `\x1B[32m${text}\x1B[39m`,
    yellow: (text) => `\x1B[33m${text}\x1B[39m`,
    blue: (text) => `\x1B[34m${text}\x1B[39m`,
    magenta: (text) => `\x1B[35m${text}\x1B[39m`,
    cyan: (text) => `\x1B[36m${text}\x1B[39m`,
    pink: (text) => `\x1B[38;5;206m${text}\x1B[39m`,
};
const levelColors = {
    debug: colors.blue,
    info: colors.green,
    warn: colors.yellow,
    error: colors.red,
    fatal: colors.magenta,
    emergency: colors.pink,
};
const customFormat = (appName, colorize = true) => {
    return winston_1.format.printf((info) => {
        const { timestamp, data, sourceClass, level, message, ms, trace_id } = info;
        let { context, stack } = info;
        if (context === undefined) {
            context = sourceClass;
        }
        if (context?.sourceClass !== undefined) {
            context = context.sourceClass;
        }
        if (stack === undefined) {
            stack = data;
        }
        if (stack?.sourceClass?.length === 0) {
            stack = undefined;
        }
        const color = colorize ? levelColors[level] || ((text) => text) : (text) => text;
        const yellow = colorize ? colors.yellow : (text) => text;
        const formattedData = stack !== undefined ? (0, util_1.inspect)(stack, { colors: true, depth: null }) : undefined;
        return ((appName !== undefined ? `${color(`[${appName}]`)} ` : '') +
            (timestamp !== undefined ? `${color(timestamp)} ` : '') +
            (level !== undefined ? `${yellow(`[${level.toUpperCase()}]`)} ` : '') +
            (trace_id !== undefined ? `${yellow(`[TraceId][${trace_id}]`)} ` : '') +
            (context !== undefined ? `${yellow(`[${context}] `)}` : '') +
            `${color(message)}` +
            (formattedData !== undefined && formattedData !== '{}' ? ` - ${formattedData}` : '') +
            (ms !== undefined ? ` ${yellow(ms)}` : ''));
    });
};
const getFormat = (formatters = []) => winston_1.format.combine(winston_1.format.timestamp({ format: 'YYYY-MM-DD HH:mm:ss' }), winston_1.format.errors({ stack: true }), winston_1.format.ms(), ...formatters);
class ConsoleTransport {
    static create(appName) {
        return new transports_1.Console({
            format: getFormat([customFormat(appName, true)]),
        });
    }
}
exports.default = ConsoleTransport;
