import { AxiosError } from 'axios';
import { LOG_LEVEL } from '../../../logger/logger.types';
export type AttachementField = {
    title: string;
    value: string;
    short: boolean;
};
export type Attachment = {
    color: '#36a64f';
    author_icon?: string;
    title?: string;
    text?: string;
    fields: AttachementField[];
    footer?: string;
    footer_icon?: string;
    ts?: number;
};
export type ErrorMessageWithAttachment = {
    attachments: Attachment[];
    blocks: [
        {
            type: string;
            text: {
                type: 'plain_text';
                text: string;
                emoji: true;
            };
        },
        {
            type: 'context';
            elements: [
                {
                    type: 'mrkdwn';
                    text: string;
                }
            ];
        },
        {
            type: 'divider';
        },
        {
            type: 'section';
            fields: [
                {
                    type: 'mrkdwn';
                    text: '*Error Context:*';
                },
                {
                    type: 'mrkdwn';
                    text: string;
                }
            ];
        },
        {
            type: 'divider';
        },
        {
            type: 'section';
            fields: [
                {
                    type: 'mrkdwn';
                    text: '*Error Response:*';
                },
                {
                    type: 'mrkdwn';
                    text: string;
                }
            ];
        },
        {
            type: 'divider';
        },
        {
            type: 'section';
            fields: [
                {
                    type: 'mrkdwn';
                    text: '*Error Message:*';
                },
                {
                    type: 'mrkdwn';
                    text: string;
                }
            ];
        }
    ];
};
export type InfoData = Error | AxiosError | unknown | unknown[];
export type Info = {
    context: string | undefined;
    message: string | undefined;
    level: keyof typeof LOG_LEVEL;
    data: InfoData | undefined;
    timestamp: string | undefined;
};
export type Levels = {
    [Level in LOG_LEVEL]: {
        send: boolean;
    };
};
export type GetMessageForSlack = {
    info: Info;
    nodeEnv: string;
    appName: string;
    levels: Levels;
};
export type SlackCreateParams = {
    nodeEnv: string;
    webhookUrl: string;
    appName: string;
    levels: Levels;
};
