import { Levels } from './winston/transports/slack.transport.types';

export enum LOG_LEVEL {
	Emergency = 'emergency', // One or more systems are unusable.
	Fatal = 'fatal', // A person must take an action immediately
	Error = 'error', // Error events are likely to cause problems
	Warn = 'warn', // Warning events might cause problems in the future and deserve eyes
	Info = 'info', // Routine information, such as ongoing status or performance
	Debug = 'debug', // Debug or trace information
}

export type LoggerModuleOptions = {
	appName: string;
	nodeEnv: string;
	slack: {
		enabled: boolean;
		levels?: Levels;
		webhook?: {
			url: string;
		};
	};
};

export const LoggerBaseKey = Symbol();
export const LoggerKey = Symbol();

export type Logger = {
	log(level: LOG_LEVEL, message: string | Error, context: string, data?: unknown): void;
	debug(message: string, context: string, data?: unknown): void;
	info(message: string, context: string, data?: unknown): void;
	warn(message: string | Error, context: string, data?: unknown): void;
	error(message: string | Error, context: string, data?: unknown): void;
	fatal(message: string | Error, context: string, data?: unknown): void;
	emergency(message: string | Error, context: string, data?: unknown): void;
};
